@@ -5,6 +5,23 @@ Channel Coding (:mod:`commpy.channelcoding`)
 
 .. module:: commpy.channelcoding
 
+Galois Fields
+=============
+
+.. autosummary::
+    :toctree: generated/
+
+    GF               -- Class representing a Galois Field object. 
+    
+Algebraic Codes
+===============
+
+.. autosummary::
+    :toctree: generated/
+
+    cyclic_code_genpoly -- Generate a cylic code generator polynomial.
+
+
 Convolutional Codes
 ===================
 
@@ -26,6 +43,13 @@ Turbo Codes
     map_decode      -- Convolutional Code decoder using MAP algorithm.
     turbo_decode    -- Turbo Decoder.
 
+LDPC Codes
+==========
+
+.. autosummary::
+
+    ldpc_decode     -- LDPC Code Decoder using Belief propagation for AWGN.
+
 Interleavers and De-interleavers
 ================================
 
@@ -39,4 +63,12 @@ Interleavers and De-interleavers
 from convcode import Trellis, conv_encode, viterbi_decode
 from interleavers import *
 from turbo import turbo_encode, map_decode, turbo_decode
+from ldpc import ldpc_decode
+from gfields import *
+from algcode import *
 
+try:
+    from numpy.testing import Tester
+    test = Tester().test
+except:
+    pass
